# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ee_extra',
 'ee_extra.Image',
 'ee_extra.ImageCollection',
 'ee_extra.JavaScript',
 'ee_extra.STAC',
 'ee_extra.Spectral']

package_data = \
{'': ['*'], 'ee_extra': ['data/*']}

install_requires = \
['earthengine-api>=0.1.259,<0.2.0', 'httplib2>=0.19.1,<0.20.0']

setup_kwargs = {
    'name': 'ee-extra',
    'version': '0.0.3',
    'description': 'A ninja Python package behind rgee, rgeeExtra and eemont.',
    'long_description': 'eeExtra\n=======\n\nA ninja Python package behind `rgee <https://github.com/r-spatial/rgee>`_, `rgeeExtra <https://github.com/r-earthengine/rgeeExtra>`_ and `eemont <https://github.com/davemlz/eemont>`_\n\n.. image:: https://img.shields.io/pypi/v/ee_extra.svg\n        :target: https://pypi.python.org/pypi/ee_extra\n        \n.. image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg\n        :target: https://opensource.org/licenses/Apache-2.0\n        \n.. image:: https://readthedocs.org/projects/ee-extra/badge/?version=latest\n        :target: https://ee-extra.readthedocs.io/en/latest/?badge=latest\n        :alt: Documentation Status\n\n.. image:: https://github.com/r-earthengine/ee_extra/actions/workflows/tests.yml/badge.svg\n        :target: https://github.com/r-earthengine/ee_extra/actions/workflows/tests.yml\n\n.. image:: https://github.com/r-earthengine/ee_extra/actions/workflows/update_awesome_spectral_indices.yml/badge.svg\n        :target: https://github.com/r-earthengine/ee_extra/actions/workflows/update_awesome_spectral_indices.yml\n\n.. image:: https://github.com/r-earthengine/ee_extra/actions/workflows/update_gee_stac_ids.yml/badge.svg\n        :target: https://github.com/r-earthengine/ee_extra/actions/workflows/update_gee_stac_ids.yml\n\n.. image:: https://github.com/r-earthengine/ee_extra/actions/workflows/update_gee_stac_scale_offset.yml/badge.svg\n        :target: https://github.com/r-earthengine/ee_extra/actions/workflows/update_gee_stac_scale_offset.yml\n        \n.. image:: https://img.shields.io/badge/David-buy%20me%20a%20coffee-ff69b4.svg\n        :target: https://www.buymeacoffee.com/davemlz\n        \n.. image:: https://img.shields.io/badge/Cesar-buy%20me%20a%20coffee-ff69b4.svg\n        :target: https://www.buymeacoffee.com/csay\n        \n.. image:: https://static.pepy.tech/personalized-badge/ee_extra?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads\n        :target: https://pepy.tech/project/ee_extra\n        \n.. image:: https://img.shields.io/badge/GEE%20Community-Developer%20Resources-00b6ff.svg\n        :target: https://developers.google.com/earth-engine/tutorials/community/developer-resources\n        \n.. image:: https://img.shields.io/twitter/follow/csaybar?style=social\n        :target: https://twitter.com/csaybar        \n\n.. image:: https://img.shields.io/twitter/follow/dmlmont?style=social\n        :target: https://twitter.com/dmlmont\n        \n.. image:: https://joss.theoj.org/papers/34696c5b62c50898b4129cbbe8befb0a/status.svg\n    :target: https://joss.theoj.org/papers/34696c5b62c50898b4129cbbe8befb0a\n    \n.. image:: https://joss.theoj.org/papers/10.21105/joss.02272/status.svg\n    :target: https://doi.org/10.21105/joss.02272\n        \n.. image:: https://img.shields.io/badge/code%20style-black-000000.svg\n    :target: https://github.com/psf/black\n  \n\n- GitHub: `https://github.com/r-earthengine/ee_extra <https://github.com/r-earthengine/ee_extra>`_\n- Documentation: `https://ee-extra.readthedocs.io/ <https://ee-extra.readthedocs.io/>`_\n- PyPI: `https://pypi.org/project/ee-extra/ <https://pypi.org/project/ee-extra/>`_\n\n\n**Table of Contents**\n\n- `Overview`_\n- `Google Earth Engine Community: Developer Resources`_\n- `Powerhouse of...`_\n- `Installation`_\n- `License`_\n- `How to cite`_\n- `Artists`_\n- `Credits`_\n\n\nOverview\n-------------------\n\n`Google Earth Engine <https://earthengine.google.com/>`_ is a cloud-based service for geospatial processing of vector and raster data. The Earth Engine platform has a `JavaScript and a Python API <https://developers.google.com/earth-engine/guides>`_ with different methods to process geospatial objects. Google Earth Engine also provides a `HUGE PETABYTE-SCALE CATALOG <https://developers.google.com/earth-engine/datasets/>`_ of raster and vector data that users can process online (e.g. Landsat Missions Image Collections, Sentinel Missions Image Collections, MODIS Products Image Collections, World Database of Protected Areas, etc.). \n\nThere are a lot of fantastic third-party GEE packages and projects around GitHub. However, most of them are coded in JavaScript or in a Python code style that is not straightforward to translate to R, Julia, or other programming languages. The main goal of **ee_extra** is to guarantee a smooth import of these projects. We re-wrote the most popular JavaScript and Python EE algorithms minimizing the dependencies to just two Python packages: **earthengine-api** and **NumPy**. Third-party GEE tools that can not meet this stipulation will not be added to **ee_extra**. Additionally, rigorous checking of code style (**black**) and documentation style (**darglint**) will be carried out to guarantee a smooth conversion of Python documentation into, for instance, R documentation (**rgee::ee_help**).\n\n.. image:: https://user-images.githubusercontent.com/16768318/119165340-ad784f80-ba5d-11eb-8d00-699eac93fb2c.png\n    :alt: ee_extra\n\n\nGoogle Earth Engine Community: Developer Resources\n-----------------------------------------------------\n\nThe ee_extra Python package can be found indirectly in the `Earth Engine Community: Developer Resources <https://developers.google.com/earth-engine/tutorials/community/developer-resources>`_ as the powerhouse of `eemont <https://github.com/davemlz/eemont>`_, `rgee <https://github.com/r-spatial/rgee>`_ and `rgeeExtra <https://github.com/r-earthengine/rgeeExtra>`_.\n\n\nPowerhouse of...\n--------------------\n\n- `rgee <https://github.com/r-spatial/rgee>`\n- `rgeeExtra <https://github.com/r-earthengine/rgeeExtra>`\n- `eemont <https://github.com/davemlz/eemont>`\n\n\nInstallation\n------------\n\nInstall the latest eemont version from PyPI by running:\n\n.. code-block::   \n      \n   pip install ee_extra\n\nUpgrade eemont by running:\n\n.. code-block::   \n      \n   pip install -U ee_extra\n\nInstall the development version from GitHub by running:\n\n.. code-block::   \n      \n   pip install git+https://github.com/r-earthengine/ee_extra\n   \nInstall the latest eemont version from conda-forge by running (SOON):\n\n.. code-block::   \n      \n   conda install -c conda-forge ee_extra\n\n\nLicense\n-------\n\nThe project is licensed under the Apache v.2.0 license.\n\n\nHow to cite\n-----------\n\nDo you like using ee_extra and think it is useful? Share the love by citing it through eemont and rgee!::\n\n   Montero, D., (2021). eemont: A Python package that extends Google Earth Engine. Journal of Open Source Software, 6(62), 3168, https://doi.org/10.21105/joss.03168\n   Aybar et al., (2020). rgee: An R package for interacting with Google Earth Engine. Journal of Open Source Software, 5(51), 2272, https://doi.org/10.21105/joss.02272\n   \nIf required, here is the BibTex for both papers!::\n\n   @article{Montero2021,\n     doi = {10.21105/joss.03168},\n     url = {https://doi.org/10.21105/joss.03168},\n     year = {2021},\n     publisher = {The Open Journal},\n     volume = {6},\n     number = {62},\n     pages = {3168},\n     author = {David Montero},\n     title = {eemont: A Python package that extends Google Earth Engine},\n     journal = {Journal of Open Source Software}\n   }\n\n   @Article{Aybar2020,\n      doi = {10.21105/joss.02272},\n      url = {https://doi.org/10.21105/joss.02272},\n      publisher = {The Open Journal},\n      title = {rgee: An R package for interacting with Google Earth Engine},\n      author = {Cesar Aybar and Quisheng Wu and Lesly Bautista and Roy Yali and Antony Barja},\n      journal = {Journal of Open Source Software},\n      year = {2020},\n    }\n\n\nArtists\n-------\n\n- `César Aybar <https://github.com/csaybar>`_: Lead Developer.\n- `David Montero Loaiza <https://github.com/davemlz>`_: Lead Developer.\n\n\nCredits\n-------\n\nSpecial thanks to `Justin Braaten <https://github.com/jdbcode>`_ for reviewing the ee_extra proposal!',
    'author': 'rgee_team',
    'author_email': 'csaybar@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/r-earthengine/ee_extra',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
